# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function
import sys

import mistune
from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters.terminal import TerminalFormatter


class HighlightRenderer(mistune.Renderer):
    def paragraph(self, text):
        return '{}\n\n'.format(text)

    def codespan(self, code):
        return '`{}`'.format(code)

    def block_code(self, code, lang):
        if not lang:
            lang = 'rust'
        lexer = get_lexer_by_name(lang, stripall=True)
        formatter = TerminalFormatter()
        text = highlight(code, lexer, formatter)
        return '{}\n'.format(text)

    def list(self, body, ordered=True):
        return '{}\n'.format(body)

    def list_item(self, text):
        return ' * {}\n'.format(text)

    def link(self, link, title, text):
        return link

    def autolink(self, link, is_email=False):
        return link

renderer = HighlightRenderer()
markdown = mistune.Markdown(renderer=renderer)


def main():
    if sys.version_info > (3,):
        code = sys.stdin.buffer.read()
    else:
        code = sys.stdin.read()
    print(markdown(code))
    return 0



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name='rusted',
    version='0.1.0',
    author='Messense Lv',
    author_email='messense@icloud.com',
    url='https://github.com/messense/rusted',
    keywords='rust explain error',
    description='Simple tool to highlight rustc --explain output',
    py_modules=['rusted'],
    install_requires=[
        'mistune>=0.7.3',
        'pygments>=2.1.3',
    ],
    entry_points={
        'console_scripts': [
            'rusted = rusted:main',
        ]
    },
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'Topic :: Utilities',
    ]
)
